@@ -12,14 +12,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
+from unittest import mock
 
 from neutron.plugins.ml2.drivers.openvswitch.agent import (
     ovs_agent_extension_api as ovs_ext_api)
-from neutron.plugins.ml2.drivers.openvswitch.agent.common import constants
-from neutron.plugins.ml2.drivers.openvswitch.agent.openflow.ovs_ofctl import (
+from neutron.plugins.ml2.drivers.openvswitch.agent.openflow.native import (
     ovs_bridge)
 from neutron.tests import base
+from neutron_lib import constants as n_consts
 from neutron_lib import context
 
 from networking_sfc.services.sfc.agent.extensions import sfc
@@ -36,9 +36,10 @@ class SfcAgentExtensionTestCase(base.BaseTestCase):
         self.sfc_ext = sfc.SfcAgentExtension()
         self.context = context.get_admin_context()
         self.connection = mock.Mock()
+        os_ken_app = mock.Mock()
         self.agent_api = ovs_ext_api.OVSAgentExtensionAPI(
-            ovs_bridge.OVSAgentBridge('br-int'),
-            ovs_bridge.OVSAgentBridge('br-tun'))
+            ovs_bridge.OVSAgentBridge('br-int', os_ken_app=os_ken_app),
+            ovs_bridge.OVSAgentBridge('br-tun', os_ken_app=os_ken_app))
         self.sfc_ext.consume_api(self.agent_api)
 
         # Don't rely on used driver
@@ -48,7 +49,7 @@ class SfcAgentExtensionTestCase(base.BaseTestCase):
         ).start()
 
         self.sfc_ext.initialize(
-            self.connection, constants.EXTENSION_DRIVER_TYPE)
+            self.connection, n_consts.EXTENSION_DRIVER_TYPE)
 
     def test_update_empty_flow_rules(self):
         self.sfc_ext.update_flow_rules(self.context, flowrule_entries={})
